fn handle_send_keys_non_typeable(
cx: &mut JSContext,
input_element: &HTMLInputElement,
text: &str,
) -> Result<bool, ErrorStatus>Expand description
We have verify previously that input element is not textual.
fn handle_send_keys_non_typeable(
cx: &mut JSContext,
input_element: &HTMLInputElement,
text: &str,
) -> Result<bool, ErrorStatus>We have verify previously that input element is not textual.